==> apache-servicecomb-java-chassis-distribution-2.2.0-src.zip: apache-servicecomb-java-chassis-distribution-2.2.0-src/foundations/foundation-common/src/test/java/org/apache/servicecomb/foundation/common/utils/TestGenericsUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.foundation.common.utils;

import java.util.List;
import java.util.Map;

import org.junit.Assert;
import org.junit.Test;
import org.springframework.core.ParameterizedTypeReference;

public class TestGenericsUtils {
  @Test
  public void testIsGenerics() {
    Assert.assertTrue(GenericsUtils.isGenericResponseType(List.class));
    Assert.assertTrue(GenericsUtils.isGenericResponseType(Map.class));
    Assert.assertTrue(GenericsUtils.isGenericResponseType(Person.class));

    Assert.assertFalse(GenericsUtils.isGenericResponseType(Man.class));
    Assert.assertFalse(GenericsUtils.isGenericResponseType(String.class));
    Assert.assertFalse(GenericsUtils.isGenericResponseType(GenericsUtils.class));

    Assert.assertFalse(GenericsUtils.isGenericResponseType(new ParameterizedTypeReference<List<Man>>() {
    }.getType()));
  }
}

class Person<T> {
  private T value;

  public T getValue() {
    return value;
  }
}

class Man extends Person<String> {

}

==> apache-servicecomb-java-chassis-distribution-3.3.0-src.zip: apache-servicecomb-java-chassis-distribution-3.3.0-src/foundations/foundation-common/src/test/java/org/apache/servicecomb/foundation/common/utils/TestGenericsUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.foundation.common.utils;

import java.util.List;
import java.util.Map;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;
import org.springframework.core.ParameterizedTypeReference;

public class TestGenericsUtils {
  @Test
  public void testIsGenerics() {
    Assertions.assertTrue(GenericsUtils.isGenericResponseType(List.class));
    Assertions.assertTrue(GenericsUtils.isGenericResponseType(Map.class));
    Assertions.assertTrue(GenericsUtils.isGenericResponseType(Person.class));

    Assertions.assertFalse(GenericsUtils.isGenericResponseType(Man.class));
    Assertions.assertFalse(GenericsUtils.isGenericResponseType(String.class));
    Assertions.assertFalse(GenericsUtils.isGenericResponseType(GenericsUtils.class));

    Assertions.assertFalse(GenericsUtils.isGenericResponseType(new ParameterizedTypeReference<List<Man>>() {
    }.getType()));
  }
}

class Person<T> {
  private T value;

  public T getValue() {
    return value;
  }
}

class Man extends Person<String> {

}
